@@ -3,8 +3,9 @@ package LWP::UserAgent::Throttled;
 use warnings;
 use strict;
 use LWP;
-use Time::HiRes;
 use LWP::UserAgent;
+use Time::HiRes;
+use URI;
 
 our @ISA = ('LWP::UserAgent');
 
@@ -14,11 +15,11 @@ LWP::UserAgent::Throttled - Throttle requests to a site
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 SYNOPSIS
 
@@ -47,9 +48,12 @@ sub send_request {
 
 	my $self = shift;
 	my $request = $_[0];
-	my $host = $request->uri()->host();
+	my $host = lc(URI->new($request->uri)->host());	# Normalize the URL
 
 	if((defined($self->{'throttle'})) && $self->{'throttle'}{$host} && $self->{'lastcallended'}{$host}) {
+		# Can't set a negative throttle
+		die "Throttle for $host must be >= 0" unless $self->{'throttle'}{$host} >= 0;
+
 		my $waittime = $self->{'throttle'}{$host} - (Time::HiRes::time() - $self->{'lastcallended'}{$host});
 
 		if($waittime > 0) {
@@ -135,6 +139,8 @@ L<LWP::UserAgent>
 
 =head1 SUPPORT
 
+This module is provided as-is without any warranty.
+
 You can find documentation for this module with the perldoc command.
 
     perldoc LWP::UserAgent::Throttled
